==> tgp_1.1-7.tar.gz: tgp/demo/moto.R <==
###################################################
### chunk number 1: 
###################################################
library(tgp)
graphics.off()

###################################################
### chunk number 2: 
###################################################
library(MASS)


###################################################
### chunk number 3: 
###################################################
moto.bgp <- bgp(X=mcycle[,1], Z=mcycle[,2], m0r1=TRUE)


###################################################
### chunk number 4: bgp
###################################################
plot(moto.bgp, main='GP,', layout='surf')


###################################################
### chunk number 5: 
###################################################
rl <- readline("press RETURN to continue")
dev.off()


###################################################
### chunk number 6: 
###################################################
moto.btlm <- btlm(X=mcycle[,1], Z=mcycle[,2], m0r1=TRUE)


###################################################
### chunk number 7: btlm
###################################################
plot(moto.btlm, main='Bayesian CART,', layout='surf')


###################################################
### chunk number 8: 
###################################################
rl <- readline("press RETURN to continue")
dev.off()


###################################################
### chunk number 9: 
###################################################
p <- tgp.default.params(2)
p$bprior <- "b0"
p$nug.p <- c(1.0,0.1,10.0,0.1)
moto.tgp <- tgp(X=mcycle[,1], Z=mcycle[,2], params=p,
	   BTE=c(2000,22000,2))


###################################################
### chunk number 10: btgp
###################################################
plot(moto.tgp, main='custom treed GP LLM,', layout='surf')


###################################################
### chunk number 11: 
###################################################
rl <- readline("press RETURN to continue")
dev.off()


###################################################
### chunk number 12: btgpq
###################################################
plot(moto.tgp, main='custom treed GP LLM,', layout='as')

==> tgp_1.2.tar.gz: tgp/demo/moto.R <==
###################################################
### chunk number 1: 
###################################################
library(tgp)
##options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 2: 
###################################################
library(MASS)


###################################################
### chunk number 3: 
###################################################
moto.bgp <- bgp(X=mcycle[,1], Z=mcycle[,2], m0r1=TRUE, verb=0)


###################################################
### chunk number 4: bgp
###################################################
plot(moto.bgp, main='GP,', layout='surf')


###################################################
### chunk number 5: 
###################################################
rl <- readline("press RETURN to continue: ")
graphics.off()


###################################################
### chunk number 6: 
###################################################
moto.btlm <- btlm(X=mcycle[,1], Z=mcycle[,2], m0r1=TRUE, verb=0)


###################################################
### chunk number 7: btlm
###################################################
plot(moto.btlm, main='Bayesian CART,', layout='surf')


###################################################
### chunk number 8: 
###################################################
rl <- readline("press RETURN to continue: ")
graphics.off()


###################################################
### chunk number 9: 
###################################################
moto.btgpllm <- btgpllm(X=mcycle[,1], Z=mcycle[,2], bprior="b0", 
                        m0r1=TRUE, verb=0)
moto.btgpllm.p <- predict(moto.btgpllm) ## using MAP


###################################################
### chunk number 10: btgp
###################################################
par(mfrow=c(1,2))
plot(moto.btgpllm, main='treed GP LLM,', layout='surf')
plot(moto.btgpllm.p, center='km', layout='surf')


###################################################
### chunk number 11: 
###################################################
rl <- readline("press RETURN to continue: ")
graphics.off()


###################################################
### chunk number 12: btgpq
###################################################
par(mfrow=c(1,2))
plot(moto.btgpllm, main='treed GP LLM,', layout='as')
plot(moto.btgpllm.p, as='ks2', layout='as')


###################################################
### chunk number 13: 
###################################################
rl <- readline("press RETURN to continue: ")
graphics.off()
